==> node-red-contrib-agilite-7.3.11.tgz: package/files/files.js <==
const Agilite = require('agilite')
const { executeHandlebars } = require('agilite-utils')
const TypeDetect = require('agilite-utils/type-detect')
const EnumsTypeDetect = require('agilite-utils/enums-type-detect')

module.exports = function (RED) {
  function Files (config) {
    RED.nodes.createNode(this, config)

    const node = this
    const field = config.field || 'payload'
    const fieldType = config.fieldType || 'msg'

    node.status({
      fill: 'blue',
      text: 'ready',
      shape: 'ring'
    })

    this.on('input', async (msg) => {
      const serverConfig = RED.nodes.getNode(config.server)
      const persistFile = config.persistFile
      const isPublic = config.isPublic
      const apiServerUrl = serverConfig.server
      const failFlow = config.failFlow
      const data = msg.payload

      let agilite = null
      let apiKey = null
      let logProfileKey = null
      let fileName = config.fileName
      let contentType = config.contentType
      let responseType = null
      let recordId = config.recordId
      let errorMessage = null
      let result = null

      const submitResponse = (response) => {
        switch (fieldType) {
          case 'msg':
            RED.util.setMessageProperty(msg, field, response.data)
            break
          case 'flow':
            node.context().flow.set(field, response.data)
            break
          case 'global':
            node.context().global.set(field, response.data)
            break
        }

        node.status({
          fill: 'green',
          text: 'Success',
          shape: 'ring'
        })

        msg.agilite.success = true
        msg.agilite.errorMessage = ''

        node.send(msg)
      }

      const submitError = (error) => {
        errorMessage = null

        if (error.response && error.response.data.errorMessage) {
          errorMessage = error.response.data.errorMessage
        } else if (error.message) {
          errorMessage = error.message
        } else {
          errorMessage = error
        }

        node.status({
          fill: 'red',
          text: 'Error',
          shape: 'ring'
        })

        msg.agilite.success = false
        msg.agilite.errorMessage = errorMessage

        if (failFlow) {
          node.error(errorMessage, msg)
        } else {
          node.send(msg)
        }
      }

      try {
        // Check if there's an Agilit-e object in MSG
        if (TypeDetect(msg.agilite) !== EnumsTypeDetect.OBJECT) msg.agilite = {}

        // Set Log Profile Key and API Key
        logProfileKey = msg.agilite.logProfileKey || ''
        apiKey = msg.agilite.apiKey || serverConfig.credentials.apiKey

        switch (config.responseType) {
          case 'base64':
            responseType = 'arraybuffer'
            break
          default:
            responseType = config.responseType
        }

        // Handlebars
        if (recordId) {
          recordId = executeHandlebars(recordId, msg)
          if ((TypeDetect(recordId) !== 'string') || (recordId === '[object Object]')) errorMessage = 'Invalid Record Id type provided. Expected a string'
        }
        if (fileName) {
          fileName = executeHandlebars(fileName, msg)
          if ((TypeDetect(fileName) !== 'string') || (fileName === '[object Object]')) errorMessage = 'Invalid File Name type provided. Expected a string'
        }
        if (contentType) {
          contentType = executeHandlebars(contentType, msg)
          if ((TypeDetect(contentType) !== 'string') || (contentType === '[object Object]')) errorMessage = 'Invalid Content Type type provided. Expected a string'
        }

        // Validate Values
        if (!apiKey) {
          errorMessage = 'No valid API Key Provided. Please authenticate with Agilit-e first'
        } else if (!apiServerUrl) {
          errorMessage = 'No Server URL Provided'
        } else {
          switch (config.actionType) {
            case '1':
            case '2':
            case '3':
              if (!recordId) errorMessage = 'Please provide a Record Id'
              break
            case '4':
              if (!fileName) errorMessage = 'Please provide a File Name (e.g. image.jpeg)'
              break
          }
        }

        if (errorMessage) return submitError(errorMessage)

        agilite = new Agilite({ apiServerUrl, apiKey })

        node.status({
          fill: 'yellow',
          text: 'Running',
          shape: 'ring'
        })

        switch (config.actionType) {
          case '1': // Get File
            result = await agilite.Files.getFile(recordId, responseType, logProfileKey)

            if (config.responseType === 'base64') {
              try {
                result = { data: result.data.toString('base64') }
              } catch (e) {
                throw new Error(e)
              }
            }
            break
          case '2': // Get File Name
            result = await agilite.Files.getFileName(recordId, logProfileKey)
            break
          case '3': // Delete File
            result = await agilite.Files.deleteFile(recordId, logProfileKey)
            break
          case '4': // Post File
            result = await agilite.Files.uploadFile(fileName, contentType, data, persistFile, isPublic, logProfileKey)
            break
          case '5': // Unzip File
            result = await agilite.Files.unzip(recordId, logProfileKey)
            break
          default:
            throw new Error('No valid Action Type specified')
        }

        submitResponse(result)
      } catch (e) {
        submitError(e)
      }
    })
  }

  RED.nodes.registerType('files', Files)
}

==> node-red-contrib-agilite-7.3.13.tgz: package/files/files.js <==
const Agilite = require('agilite')
const { compileTemplate } = require('agilite-utils')
const TypeDetect = require('agilite-utils/type-detect')
const EnumsTypeDetect = require('agilite-utils/enums-type-detect')

module.exports = function (RED) {
  function Files (config) {
    RED.nodes.createNode(this, config)

    const node = this
    const field = config.field || 'payload'
    const fieldType = config.fieldType || 'msg'

    node.status({
      fill: 'blue',
      text: 'ready',
      shape: 'ring'
    })

    this.on('input', async (msg) => {
      const serverConfig = RED.nodes.getNode(config.server)
      const persistFile = config.persistFile
      const isPublic = config.isPublic
      const apiServerUrl = serverConfig.server
      const failFlow = config.failFlow
      const data = msg.payload

      let agilite = null
      let apiKey = null
      let logProfileKey = null
      let fileName = config.fileName
      let contentType = config.contentType
      let responseType = null
      let recordId = config.recordId
      let errorMessage = null
      let result = null

      const submitResponse = (response) => {
        switch (fieldType) {
          case 'msg':
            RED.util.setMessageProperty(msg, field, response.data)
            break
          case 'flow':
            node.context().flow.set(field, response.data)
            break
          case 'global':
            node.context().global.set(field, response.data)
            break
        }

        node.status({
          fill: 'green',
          text: 'Success',
          shape: 'ring'
        })

        msg.agilite.success = true
        msg.agilite.errorMessage = ''

        node.send(msg)
      }

      const submitError = (error) => {
        errorMessage = null

        if (error.response && error.response.data.errorMessage) {
          errorMessage = error.response.data.errorMessage
        } else if (error.message) {
          errorMessage = error.message
        } else {
          errorMessage = error
        }

        node.status({
          fill: 'red',
          text: 'Error',
          shape: 'ring'
        })

        msg.agilite.success = false
        msg.agilite.errorMessage = errorMessage

        if (failFlow) {
          node.error(errorMessage, msg)
        } else {
          node.send(msg)
        }
      }

      try {
        // Check if there's an Agilit-e object in MSG
        if (TypeDetect(msg.agilite) !== EnumsTypeDetect.OBJECT) msg.agilite = {}

        // Set Log Profile Key and API Key
        logProfileKey = msg.agilite.logProfileKey || ''
        apiKey = msg.agilite.apiKey || serverConfig.credentials.apiKey

        switch (config.responseType) {
          case 'base64':
            responseType = 'arraybuffer'
            break
          default:
            responseType = config.responseType
        }

        // Handlebars
        if (recordId) {
          recordId = compileTemplate(recordId, msg)
          if ((TypeDetect(recordId) !== 'string') || (recordId === '[object Object]')) errorMessage = 'Invalid Record Id type provided. Expected a string'
        }
        if (fileName) {
          fileName = compileTemplate(fileName, msg)
          if ((TypeDetect(fileName) !== 'string') || (fileName === '[object Object]')) errorMessage = 'Invalid File Name type provided. Expected a string'
        }
        if (contentType) {
          contentType = compileTemplate(contentType, msg)
          if ((TypeDetect(contentType) !== 'string') || (contentType === '[object Object]')) errorMessage = 'Invalid Content Type type provided. Expected a string'
        }

        // Validate Values
        if (!apiKey) {
          errorMessage = 'No valid API Key Provided. Please authenticate with Agilit-e first'
        } else if (!apiServerUrl) {
          errorMessage = 'No Server URL Provided'
        } else {
          switch (config.actionType) {
            case '1':
            case '2':
            case '3':
              if (!recordId) errorMessage = 'Please provide a Record Id'
              break
            case '4':
              if (!fileName) errorMessage = 'Please provide a File Name (e.g. image.jpeg)'
              break
          }
        }

        if (errorMessage) return submitError(errorMessage)

        agilite = new Agilite({ apiServerUrl, apiKey })

        node.status({
          fill: 'yellow',
          text: 'Running',
          shape: 'ring'
        })

        switch (config.actionType) {
          case '1': // Get File
            result = await agilite.Files.getFile(recordId, responseType, logProfileKey)

            if (config.responseType === 'base64') {
              try {
                result = { data: result.data.toString('base64') }
              } catch (e) {
                throw new Error(e)
              }
            }
            break
          case '2': // Get File Name
            result = await agilite.Files.getFileName(recordId, logProfileKey)
            break
          case '3': // Delete File
            result = await agilite.Files.deleteFile(recordId, logProfileKey)
            break
          case '4': // Post File
            result = await agilite.Files.uploadFile(fileName, contentType, data, persistFile, isPublic, logProfileKey)
            break
          case '5': // Unzip File
            result = await agilite.Files.unzip(recordId, logProfileKey)
            break
          default:
            throw new Error('No valid Action Type specified')
        }

        submitResponse(result)
      } catch (e) {
        submitError(e)
      }
    })
  }

  RED.nodes.registerType('files', Files)
}
